==> pkg-perl-tools_0.13.tar.xz: pkg-perl-tools-0.13/lintian/checks/pkg-perl/usr-lib-perl5.pm <==
# pkg-perl/usr-lib-perl5 -- lintian check script for checking for mentions of usr/lib/perl5 in debian/* -*- perl -*-
#
# Copyright © 2013 Niels Thykier <niels@thykier.net>
# Copyright © 2013 gregor herrmann <gregoa@debian.org>
# Copyright © 2013 Axel Beckert <abe@debian.org>
# Copyright © 2014 Damyan Ivanov <dmn@debian.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::pkg_perl::usr_lib_perl5;

use strict;
use warnings;

use Lintian::Tags qw(tag);
use File::Basename qw(basename);

sub run {
    my ( $pkg, $type, $info, $proc, $group ) = @_;

    my $d = $info->debfiles;
    for my $f (glob("$d/*")) {
        my $short = basename($f);
        next if $short =~ /^\.\.?$/;
        next if $short eq 'changelog';
        open my $fh, '<', $f;
        while (<$fh>) {
            # ignore comments
            s/#.*//;
            tag( 'usr-lib-perl5-mentioned', $short ), last if m{usr/lib/perl5};
        }
        close($fh);
    }
}

1;

==> pkg-perl-tools_0.19.tar.xz: pkg-perl-tools-0.19/lintian/checks/pkg-perl/usr-lib-perl5.pm <==
# pkg-perl/usr-lib-perl5 -- lintian check script for checking for mentions of usr/lib/perl5 in debian/* -*- perl -*-
#
# Copyright © 2013 Niels Thykier <niels@thykier.net>
# Copyright © 2013 gregor herrmann <gregoa@debian.org>
# Copyright © 2013-2014 Axel Beckert <abe@debian.org>
# Copyright © 2014 Damyan Ivanov <dmn@debian.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::pkg_perl::usr_lib_perl5;

use strict;
use warnings;

use Lintian::Tags qw(tag);
use Lintian::Util qw(is_ancestor_of);
use File::Basename qw(basename);

sub run {
    my ( $pkg, $type, $info, $proc, $group ) = @_;

    my $d = $info->index_resolved_path("debian/");
    for my $f ($d->children) {
        my $short = $f->basename();
        next if $short eq 'changelog';
        # Skip symlinks and other nasty stuff
        next unless $f->is_file && $f->is_open_ok;
        my $contents = $f->file_contents;
        # ignore comments
        $contents =~ s/#.*$//m;
        tag( 'usr-lib-perl5-mentioned', $short )
            if $contents =~ m{usr/lib/perl5};
    }
}

1;
